moment_cone: Kronecker and fermionic moment cones
=================================================

Description
-----------

Computations with Kronecker and fermionic moment cones.

License
-------

MIT

Upstream Contact
----------------

- https://github.com/ea-icj/moment_cone
